@@ -23,10 +23,10 @@
 
 G_BEGIN_DECLS
 
-extern GPtrArray* remmina_widget_pool;
-
+void remmina_widget_pool_init (void);
 void remmina_widget_pool_register (GtkWidget *widget);
 GtkWidget* remmina_widget_pool_find (GType type, const gchar *tag);
+GtkWidget* remmina_widget_pool_find_by_window (GType type, GdkWindow *window);
 
 G_END_DECLS
 
